@@ -1,12 +1,15 @@
 """ Apps file for setting core package when app is ready
 """
+import sys
+
 from django.apps import AppConfig
 
 
 class ComposerAppConfig(AppConfig):
     """ Core composer application settings
     """
-    name = 'core_composer_app'
+
+    name = "core_composer_app"
 
     def ready(self):
         """ Run when the app is ready.
@@ -14,5 +17,7 @@ class ComposerAppConfig(AppConfig):
         Returns:
 
         """
-        import core_composer_app.permissions.discover as discover
-        discover.init_permissions()
+        if "migrate" not in sys.argv:
+            import core_composer_app.permissions.discover as discover
+
+            discover.init_permissions()
